@@ -390,7 +390,10 @@ class Application extends ApplicationConfig
             $parameter = $default;
         }
         if (preg_match('/^(true|on|yes)$/i',$parameter)) {
-            $parameter = 1;
+            $parameter = true;
+        }
+        if (preg_match('/^(false|off|no)$/i',$parameter)) {
+            $parameter = false;
         }
 
         return $parameter;
