@@ -155,6 +155,9 @@ $App->setSession('Backend',$Backend);   // store backend for this session
 $App->setSession('archive',$archive);   // store current archive
 $App->setSession('FilterList',$FilterList);
 
+if ($USER->getAuthParam('AUTHBY') == 'db') { // show admin ui
+    $App->setSession('USERPANEL',true);
+}
 
 // set language on change and after login for 32 days
 setcookie("BENNO_LANGUAGE", $LANG, time()+2764800, dirname($_SERVER['REQUEST_URI']));
