@@ -113,6 +113,17 @@ class User extends UserDA
     var $restdata;
 
 
+   /**
+     * authparam
+     *
+     * Authentication parameters
+     *
+     * @access public
+     * @var array
+     */
+    var $authparam;
+
+
     /**
      * constructor
      *
@@ -124,9 +135,10 @@ class User extends UserDA
      * @param string $role optional
      * @param array $addresses optional
      * @param array $restdata optional
+     * @param array $authparam optional
      * @return object
      */
-    function User ($id,$password='',$name='',$archive=array(),$role='',$adresses=array(),$restdata=array())
+    function User ($id,$password='',$name='',$archive=array(),$role='',$adresses=array(),$restdata=array(),$authparam=array())
     {
         $this->id = $id;
         $this->password = $password;
@@ -134,7 +146,8 @@ class User extends UserDA
         $this->archive = $archive;
         $this->role = $role;
         $this->addresses = $adresses;
-        $this->restdata= $restdata;
+        $this->restdata = $restdata;
+        $this->authparam = $authparam;
     }
 
     function getAuthzLevel () {
@@ -143,7 +156,7 @@ class User extends UserDA
         if ($this->role == 'USER')    { return 2; }
     }
 
-    function setPassword ($pass) { $this->password = $password; }
+    function setPassword ($pass) { $this->password = password_hash($pass,PASSWORD_BCRYPT); }
 
     function getName () { return $this->name; }
     function setName ($name) { $this->name = $name; }
@@ -156,5 +169,8 @@ class User extends UserDA
 
     function setRestData ($restdata) { $this->restdata = $restdata; }
     function getRestData () { return $this->restdata; }
+
+    function getAuthParam ($param) { return $this->authparam[$param]; }
+
 }
 ?>
