@@ -56,17 +56,21 @@ class UserDA extends Persistence
      * @access public
      * @return array entries
      */
-    function FetchList ()
+    public static function FetchList ($archive)
     {
         global $App;
         $entries = array();
 
-        $list = Persistence::OdList('User','id');
-        foreach ($list as $row) {
+        $DB = $App->DB;
+        $sql = "SELECT * FROM user WHERE archive = '".$archive."' ORDER BY name";
+        $res = $DB->query($sql);
+        while ($row = $res->fetchRow()) {
             $obj = new User($row['id']);
             $obj->load();
+            if (!$obj->name) $obj->name = $obj->id;
             array_push($entries,$obj);
         }
+
         return $entries;
     }
 
@@ -219,8 +223,42 @@ class UserDA extends Persistence
     // Overwrites Persistence::save()
     function save ()
     {
-        error_log("[User::save] not yet implemented\n");
-        return FALSE;
+        global $App;
+
+        $DB = $App->DB;
+        $DB->startTransaction();
+        $sql = "DELETE FROM address WHERE id = '$this->id'";
+        $res = $DB->query($sql);
+
+        $sql = "INSERT INTO address (id,address) VALUES (?,?)";
+        $sth = $DB->db->prepare($sql);
+        try {
+            foreach ($this->addresses as $address) {
+                $sth->bindValue(1,$this->id);
+                $sth->bindValue(2,$address);
+                $res = $sth->execute();
+            }
+        }
+        catch(PDOException $e){ 
+            $App->log('WARN '.$e->getMessage(),0);
+        }
+
+        $sql = "DELETE FROM user WHERE id = '$this->id'";
+        $res = $DB->query($sql);
+        $sql = "INSERT INTO user (id,name,password,archive,role) VALUES (?,?,?,?,?)";
+        $sth = $DB->db->prepare($sql);
+        try {
+            $sth->bindValue(1,$this->id);
+            $sth->bindValue(2,$this->name);
+            $sth->bindValue(3,$this->password);
+            $sth->bindValue(4,@implode($this->archive));
+            $sth->bindValue(5,$this->role);
+            $res = $sth->execute();
+        }
+        catch(PDOException $e){ 
+            $App->log('WARN '.$e->getMessage(),0);
+        }
+        $DB->endTransaction();
     }
 
 
@@ -251,6 +289,10 @@ class UserDA extends Persistence
                 case 'MAIL':
                     array_push($this->addresses,$data);
                     break;
+                case 'AUTHPARAM':
+                    $this->authparam = array_merge(
+                            $this->authparam,$this->_parse_param($data));
+                    break;
                 case 'USERID':
                     $this->id = $data;
                     break;
@@ -282,5 +324,14 @@ class UserDA extends Persistence
         return FALSE;
     }
 
+
+    // split ':' into array
+    function _parse_param($authparam)
+    {
+        list($param,$value) = explode(':',$authparam,2);
+        $p[$param] = $value;
+
+        return $p;
+    }
 }
 ?>
